@@ -1011,21 +1011,23 @@ typedef guint64 FwupdPluginFlags;
  * @FWUPD_INSTALL_FLAG_IGNORE_POWER:		Ignore requirement of external power source
  *(Deprecated since 1.7.0)
  * @FWUPD_INSTALL_FLAG_NO_SEARCH:		Do not use heuristics when parsing the image
+ * @FWUPD_INSTALL_FLAG_IGNORE_REQUIREMENTS:	Ignore version requirement checks
  *
  * Flags to set when performing the firmware update or install.
  **/
 typedef enum {
-	FWUPD_INSTALL_FLAG_NONE = 0,			 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_OFFLINE = 1 << 0,		 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_ALLOW_REINSTALL = 1 << 1,	 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_ALLOW_OLDER = 1 << 2,	 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_FORCE = 1 << 3,		 /* Since: 0.7.1 */
-	FWUPD_INSTALL_FLAG_NO_HISTORY = 1 << 4,		 /* Since: 1.0.8 */
-	FWUPD_INSTALL_FLAG_ALLOW_BRANCH_SWITCH = 1 << 5, /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM = 1 << 6,	 /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_VID_PID = 1 << 7,	 /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_POWER = 1 << 8,	 /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_NO_SEARCH = 1 << 9,		 /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_NONE = 0,			  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_OFFLINE = 1 << 0,		  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_ALLOW_REINSTALL = 1 << 1,	  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_ALLOW_OLDER = 1 << 2,	  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_FORCE = 1 << 3,		  /* Since: 0.7.1 */
+	FWUPD_INSTALL_FLAG_NO_HISTORY = 1 << 4,		  /* Since: 1.0.8 */
+	FWUPD_INSTALL_FLAG_ALLOW_BRANCH_SWITCH = 1 << 5,  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM = 1 << 6,	  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_VID_PID = 1 << 7,	  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_POWER = 1 << 8,	  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_NO_SEARCH = 1 << 9,		  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_REQUIREMENTS = 1 << 10, /* Since: 1.9.21 */
 	/*< private >*/
 	FWUPD_INSTALL_FLAG_LAST
 } FwupdInstallFlags;
@@ -1104,6 +1106,7 @@ typedef enum {
  * @FWUPD_VERSION_FORMAT_SURFACE:		Microsoft Surface 8b.16b.8b
  * @FWUPD_VERSION_FORMAT_DELL_BIOS:		Dell BIOS BB.CC.DD style
  * @FWUPD_VERSION_FORMAT_HEX:			Hexadecimal 0xAABCCDD style
+ * @FWUPD_VERSION_FORMAT_DELL_BIOS_MSB: 	Dell BIOS AA.BB.CC style
  *
  * The flags used when parsing version numbers.
  *
@@ -1124,6 +1127,7 @@ typedef enum {
 	FWUPD_VERSION_FORMAT_SURFACE,	     /* Since: 1.3.4 */
 	FWUPD_VERSION_FORMAT_DELL_BIOS,	     /* Since: 1.3.6 */
 	FWUPD_VERSION_FORMAT_HEX,	     /* Since: 1.4.0 */
+	FWUPD_VERSION_FORMAT_DELL_BIOS_MSB,  /* Since: 1.9.24 */
 	/*< private >*/
 	FWUPD_VERSION_FORMAT_LAST
 } FwupdVersionFormat;
