@@ -13,8 +13,8 @@
 G_BEGIN_DECLS
 
 GVariant *
-fwupd_plugin_to_variant(FwupdPlugin *self);
+fwupd_plugin_to_variant(FwupdPlugin *self) G_GNUC_NON_NULL(1);
 void
-fwupd_plugin_to_json(FwupdPlugin *self, JsonBuilder *builder);
+fwupd_plugin_to_json(FwupdPlugin *self, JsonBuilder *builder) G_GNUC_NON_NULL(1, 2);
 
 G_END_DECLS
