@@ -20,6 +20,9 @@ G_DEFINE_TYPE(FuAverHidDevice, fu_aver_hid_device, FU_TYPE_HID_DEVICE)
 #define FU_AVER_HID_DEVICE_GET_STATUS_POLL_INTERVAL 1000 /* ms */
 #define FU_AVER_HID_DEVICE_POLL_INTERVAL	    5000 /* ms */
 #define FU_AVER_HID_DEVICE_ISP_RETRY_COUNT	    300
+#define FU_AVER_HID_DEVICE_ISP_UNTAR_WAIT_COUNT	    600
+
+#define FU_AVER_HID_FLAG_DUAL_ISP (1 << 0)
 
 static gboolean
 fu_aver_hid_device_transfer(FuAverHidDevice *self, GByteArray *req, GByteArray *res, GError **error)
@@ -56,27 +59,25 @@ fu_aver_hid_device_transfer(FuAverHidDevice *self, GByteArray *req, GByteArray *
 }
 
 static gboolean
-fu_aver_hid_device_poll(FuDevice *device, GError **error)
+fu_aver_hid_device_ensure_status(FuAverHidDevice *self, GError **error)
 {
-	FuAverHidDevice *self = FU_AVER_HID_DEVICE(device);
 	g_autoptr(GByteArray) req = fu_struct_aver_hid_req_isp_new();
 	g_autoptr(GByteArray) res = fu_struct_aver_hid_res_isp_status_new();
-	g_autoptr(FuDeviceLocker) locker = NULL;
 
-	locker = fu_device_locker_new(device, error);
-	if (locker == NULL)
-		return FALSE;
 	fu_struct_aver_hid_req_isp_set_custom_isp_cmd(req, FU_AVER_HID_CUSTOM_ISP_CMD_STATUS);
 	if (!fu_aver_hid_device_transfer(self, req, res, error))
 		return FALSE;
 	if (!fu_struct_aver_hid_res_isp_status_validate(res->data, res->len, 0x0, error))
 		return FALSE;
 	if (fu_struct_aver_hid_res_isp_status_get_status(res) == FU_AVER_HID_STATUS_BUSY) {
-		fu_device_add_problem(device, FWUPD_DEVICE_PROBLEM_IN_USE);
-	} else {
-		fu_device_remove_problem(device, FWUPD_DEVICE_PROBLEM_IN_USE);
+		g_set_error(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_BUSY,
+			    "device has status %s",
+			    fu_aver_hid_status_to_string(
+				fu_struct_aver_hid_res_isp_status_get_status(res)));
+		return FALSE;
 	}
-
 	return TRUE;
 }
 
@@ -116,8 +117,8 @@ fu_aver_hid_device_setup(FuDevice *device, GError **error)
 	if (!FU_DEVICE_CLASS(fu_aver_hid_device_parent_class)->setup(device, error))
 		return FALSE;
 
-	/* using isp status requests as polling device requests */
-	if (!fu_aver_hid_device_poll(device, error))
+	/* ensure that the device status is updateable */
+	if (!fu_aver_hid_device_ensure_status(self, error))
 		return FALSE;
 
 	/* get the version from the hardware while open */
@@ -155,9 +156,15 @@ fu_aver_hid_device_isp_file_dnload(FuAverHidDevice *self,
 		g_autoptr(GByteArray) res = fu_struct_aver_hid_res_isp_status_new();
 
 		/* copy in payload */
-		fu_struct_aver_hid_req_isp_file_dnload_set_custom_isp_cmd(
-		    req,
-		    FU_AVER_HID_CUSTOM_ISP_CMD_FILE_DNLOAD);
+		if (fu_device_has_private_flag(FU_DEVICE(self), FU_AVER_HID_FLAG_DUAL_ISP)) {
+			fu_struct_aver_hid_req_isp_file_dnload_set_custom_isp_cmd(
+			    req,
+			    FU_AVER_HID_CUSTOM_ISP_CMD_ALL_FILE_DNLOAD);
+		} else {
+			fu_struct_aver_hid_req_isp_file_dnload_set_custom_isp_cmd(
+			    req,
+			    FU_AVER_HID_CUSTOM_ISP_CMD_FILE_DNLOAD);
+		}
 		if (!fu_memcpy_safe(req->data,
 				    req->len,
 				    FU_STRUCT_AVER_HID_REQ_ISP_FILE_DNLOAD_OFFSET_DATA, /* dst */
@@ -230,9 +237,15 @@ fu_aver_hid_device_isp_file_start(FuAverHidDevice *self,
 	g_autoptr(GByteArray) req = fu_struct_aver_hid_req_isp_file_start_new();
 	g_autoptr(GByteArray) res = fu_struct_aver_hid_res_isp_status_new();
 
-	fu_struct_aver_hid_req_isp_file_start_set_custom_isp_cmd(
-	    req,
-	    FU_AVER_HID_CUSTOM_ISP_CMD_FILE_START);
+	if (fu_device_has_private_flag(FU_DEVICE(self), FU_AVER_HID_FLAG_DUAL_ISP)) {
+		fu_struct_aver_hid_req_isp_file_start_set_custom_isp_cmd(
+		    req,
+		    FU_AVER_HID_CUSTOM_ISP_CMD_ALL_FILE_START);
+	} else {
+		fu_struct_aver_hid_req_isp_file_start_set_custom_isp_cmd(
+		    req,
+		    FU_AVER_HID_CUSTOM_ISP_CMD_FILE_START);
+	}
 	if (!fu_struct_aver_hid_req_isp_file_start_set_file_name(req, name, error))
 		return FALSE;
 	fu_struct_aver_hid_req_isp_file_start_set_file_size(req, sz);
@@ -249,8 +262,15 @@ fu_aver_hid_device_isp_file_end(FuAverHidDevice *self, gsize sz, const gchar *na
 	g_autoptr(GByteArray) req = fu_struct_aver_hid_req_isp_file_end_new();
 	g_autoptr(GByteArray) res = fu_struct_aver_hid_res_isp_status_new();
 
-	fu_struct_aver_hid_req_isp_file_end_set_custom_isp_cmd(req,
-							       FU_AVER_HID_CUSTOM_ISP_CMD_FILE_END);
+	if (fu_device_has_private_flag(FU_DEVICE(self), FU_AVER_HID_FLAG_DUAL_ISP)) {
+		fu_struct_aver_hid_req_isp_file_end_set_custom_isp_cmd(
+		    req,
+		    FU_AVER_HID_CUSTOM_ISP_CMD_ALL_FILE_END);
+	} else {
+		fu_struct_aver_hid_req_isp_file_end_set_custom_isp_cmd(
+		    req,
+		    FU_AVER_HID_CUSTOM_ISP_CMD_FILE_END);
+	}
 	if (!fu_struct_aver_hid_req_isp_file_end_set_file_name(req, name, error))
 		return FALSE;
 	fu_struct_aver_hid_req_isp_file_end_set_end_flag(req, 1);
@@ -262,13 +282,46 @@ fu_aver_hid_device_isp_file_end(FuAverHidDevice *self, gsize sz, const gchar *na
 	return TRUE;
 }
 
+static gboolean
+fu_aver_hid_device_wait_for_untar_cb(FuDevice *device, gpointer user_data, GError **error)
+{
+	FuAverHidDevice *self = FU_AVER_HID_DEVICE(device);
+	g_autoptr(GByteArray) req = fu_struct_aver_hid_req_isp_file_end_new();
+	g_autoptr(GByteArray) res = fu_struct_aver_hid_res_isp_status_new();
+
+	fu_struct_aver_hid_req_isp_set_custom_isp_cmd(req, FU_AVER_HID_CUSTOM_ISP_CMD_STATUS);
+	if (!fu_aver_hid_device_transfer(self, req, res, error))
+		return FALSE;
+
+	g_info("isp status: %s",
+	       fu_aver_hid_status_to_string(fu_struct_aver_hid_res_isp_status_get_status(res)));
+	if (fu_struct_aver_hid_res_isp_status_get_status(res) != FU_AVER_HID_STATUS_WAITUSR) {
+		g_set_error(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_BUSY,
+			    "device has status %s",
+			    fu_aver_hid_status_to_string(
+				fu_struct_aver_hid_res_isp_status_get_status(res)));
+		return FALSE;
+	}
+	return TRUE;
+}
+
 static gboolean
 fu_aver_hid_device_isp_start(FuAverHidDevice *self, GError **error)
 {
 	g_autoptr(GByteArray) req = fu_struct_aver_hid_req_isp_new();
 	g_autoptr(GByteArray) res = fu_struct_aver_hid_res_isp_status_new();
 
-	fu_struct_aver_hid_req_isp_start_set_custom_isp_cmd(req, FU_AVER_HID_CUSTOM_ISP_CMD_START);
+	if (fu_device_has_private_flag(FU_DEVICE(self), FU_AVER_HID_FLAG_DUAL_ISP)) {
+		fu_struct_aver_hid_req_isp_start_set_custom_isp_cmd(
+		    req,
+		    FU_AVER_HID_CUSTOM_ISP_CMD_ALL_START);
+	} else {
+		fu_struct_aver_hid_req_isp_start_set_custom_isp_cmd(
+		    req,
+		    FU_AVER_HID_CUSTOM_ISP_CMD_START);
+	}
 	if (!fu_aver_hid_device_transfer(self, req, res, error))
 		return FALSE;
 	if (!fu_struct_aver_hid_res_isp_status_validate(res->data, res->len, 0x0, error))
@@ -388,6 +441,15 @@ fu_aver_hid_device_write_firmware(FuDevice *device,
 	/* ISP_FILE_END */
 	if (!fu_aver_hid_device_isp_file_end(self, fw_size, aver_fw_name, error))
 		return FALSE;
+
+	/* poll for the file untar progress */
+	if (!fu_device_retry_full(device,
+				  fu_aver_hid_device_wait_for_untar_cb,
+				  FU_AVER_HID_DEVICE_ISP_UNTAR_WAIT_COUNT,
+				  FU_AVER_HID_DEVICE_GET_STATUS_POLL_INTERVAL,
+				  fu_progress_get_child(progress),
+				  error))
+		return FALSE;
 	fu_progress_step_done(progress);
 
 	/* ISP_START */
@@ -440,13 +502,13 @@ fu_aver_hid_device_init(FuAverHidDevice *self)
 	fu_device_set_remove_delay(FU_DEVICE(self), 150000);
 	fu_hid_device_add_flag(FU_HID_DEVICE(self), FU_HID_DEVICE_FLAG_RETRY_FAILURE);
 	fu_hid_device_add_flag(FU_HID_DEVICE(self), FU_HID_DEVICE_FLAG_AUTODETECT_EPS);
+	fu_device_register_private_flag(FU_DEVICE(self), FU_AVER_HID_FLAG_DUAL_ISP, "dual-isp");
 }
 
 static void
 fu_aver_hid_device_class_init(FuAverHidDeviceClass *klass)
 {
 	FuDeviceClass *klass_device = FU_DEVICE_CLASS(klass);
-	klass_device->poll = fu_aver_hid_device_poll;
 	klass_device->setup = fu_aver_hid_device_setup;
 	klass_device->prepare_firmware = fu_aver_hid_device_prepare_firmware;
 	klass_device->write_firmware = fu_aver_hid_device_write_firmware;
